# Changelog

## [0.6.1](https://github.com/SoferAi/torah-dl/compare/v0.6.0...v0.6.1) (2026-02-25)


### Bug Fixes

* kol halashon title and other url type fix ([#190](https://github.com/SoferAi/torah-dl/issues/190)) ([ea5b831](https://github.com/SoferAi/torah-dl/commit/ea5b8314fe91c156b1478cb9a935ae9714259b32))

## [0.6.0](https://github.com/SoferAi/torah-dl/compare/v0.5.0...v0.6.0) (2026-02-25)


### Features

* added kol halashon extractor ([#189](https://github.com/SoferAi/torah-dl/issues/189)) ([a70f173](https://github.com/SoferAi/torah-dl/commit/a70f17397a5530c64f4033fde49405eb46c74dd9))
* **cli:** improve extract command output formatting ([#142](https://github.com/SoferAi/torah-dl/issues/142)) ([38d9ec6](https://github.com/SoferAi/torah-dl/commit/38d9ec66862905378498d117d62c641a8529acbc))
* **core:** add AllParsha.org audio content extractor ([#123](https://github.com/SoferAi/torah-dl/issues/123)) ([f503fae](https://github.com/SoferAi/torah-dl/commit/f503faee1801b412e3d6535f497e19a8e50b8d99))
* **core:** add Etzion.org audio/video content extractor ([#128](https://github.com/SoferAi/torah-dl/issues/128)) ([33cfb3e](https://github.com/SoferAi/torah-dl/commit/33cfb3ee40a3f319879c69cdca42385f5751e341))
* **core:** add Mp3Shiur.com audio content extractor ([#146](https://github.com/SoferAi/torah-dl/issues/146)) ([35b285f](https://github.com/SoferAi/torah-dl/commit/35b285fdc2a6a335d6d6801f0cf5ccdfcceeedc2))
* **core:** add Nishmat.net audio content extractor ([#143](https://github.com/SoferAi/torah-dl/issues/143)) ([8052dd9](https://github.com/SoferAi/torah-dl/commit/8052dd99659b5c91813da17c0e3e3f8e742135e2))
* **core:** add Orayta.org audio/youtube content extractor ([#135](https://github.com/SoferAi/torah-dl/issues/135)) ([a308202](https://github.com/SoferAi/torah-dl/commit/a30820233307d2cf20308e5319f1f94973fdf237))
* **core:** add TorahInAmerica.com audio content extractor ([#145](https://github.com/SoferAi/torah-dl/issues/145)) ([3903989](https://github.com/SoferAi/torah-dl/commit/390398940c4a4e960c8b8e4b0a0c37ecc4bc97cf))
* **core:** add Torahweb.org audio content extractor ([#141](https://github.com/SoferAi/torah-dl/issues/141)) ([3488d48](https://github.com/SoferAi/torah-dl/commit/3488d48db4485687f9ff040e84c1cb2891bc5b2d))
* demo website ([#78](https://github.com/SoferAi/torah-dl/issues/78)) ([1d8c1a5](https://github.com/SoferAi/torah-dl/commit/1d8c1a5150c76565035d041e0f2e761815336b6c))


### Bug Fixes

* add lib ([#82](https://github.com/SoferAi/torah-dl/issues/82)) ([70c7684](https://github.com/SoferAi/torah-dl/commit/70c76847b8ff5fedbc548e558ec82ac5b09dcbc7))
* conventional commits ([#136](https://github.com/SoferAi/torah-dl/issues/136)) ([c56ae29](https://github.com/SoferAi/torah-dl/commit/c56ae298b10cd0b404388cef5e91a5c457bf747d))
* **deps:** update dependency lucide-react to ^0.514.0 ([#105](https://github.com/SoferAi/torah-dl/issues/105)) ([3951c62](https://github.com/SoferAi/torah-dl/commit/3951c62cc87a4cd87e92f6cedaebb4c17b0ccee8))
* **deps:** update dependency tailwind-merge to v3.3.1 ([#112](https://github.com/SoferAi/torah-dl/issues/112)) ([dc12915](https://github.com/SoferAi/torah-dl/commit/dc12915419f0841203cdaf9ba63a4b80c71f8b19))
* **deps:** update nextjs monorepo to v15.3.3 ([#98](https://github.com/SoferAi/torah-dl/issues/98)) ([d56a300](https://github.com/SoferAi/torah-dl/commit/d56a30075aeb9a674a9e1f275c2bc405775d46d8))
* **deps:** update nextjs monorepo to v15.3.4 ([#121](https://github.com/SoferAi/torah-dl/issues/121)) ([194ea5d](https://github.com/SoferAi/torah-dl/commit/194ea5dc53b23c0061d7cff923a19b00c76562d2))
* **deps:** update nextjs monorepo to v15.5.9 ([#149](https://github.com/SoferAi/torah-dl/issues/149)) ([02cfa41](https://github.com/SoferAi/torah-dl/commit/02cfa41292203c6aab68f1f3d877a50492c620be))
* flakey tests ([#93](https://github.com/SoferAi/torah-dl/issues/93)) ([e499f37](https://github.com/SoferAi/torah-dl/commit/e499f3763864d93177d4a5a400c6caaaf870e6be))

## [0.5.0](https://github.com/SoferAi/torah-dl/compare/v0.4.1...v0.5.0) (2025-03-30)


### Features

* naaleh support ([#52](https://github.com/SoferAi/torah-dl/issues/52)) ([e918079](https://github.com/SoferAi/torah-dl/commit/e918079c353d4a18e56460cfd57e2ec747742edc))


### Bug Fixes

* semgrep ([#53](https://github.com/SoferAi/torah-dl/issues/53)) ([9433dc9](https://github.com/SoferAi/torah-dl/commit/9433dc982e5fd83a79c02cb58a2fc946efc5950a))
* update packages to working versions ([#48](https://github.com/SoferAi/torah-dl/issues/48)) ([8e2a69b](https://github.com/SoferAi/torah-dl/commit/8e2a69b5e50fac36574f26e136cd3fd1fa6bb5ee))

## [0.4.1](https://github.com/SoferAi/torah-dl/compare/v0.4.0...v0.4.1) (2025-02-02)


### Bug Fixes

* use lower versions for compatibility ([#25](https://github.com/SoferAi/torah-dl/issues/25)) ([065c73d](https://github.com/SoferAi/torah-dl/commit/065c73d7d13d9cb33781056089d372eee33716a5))

## [0.4.0](https://github.com/SoferAi/torah-dl/compare/v0.3.1...v0.4.0) (2025-01-27)


### Features

* add torahdownloads.org ([c33725a](https://github.com/SoferAi/torah-dl/commit/c33725aa5b938b7d0b3dd3e24a90d93168e9e047))
* alldaf support ([#22](https://github.com/SoferAi/torah-dl/issues/22)) ([fc75ee3](https://github.com/SoferAi/torah-dl/commit/fc75ee33e69f1bcd8c9080dbe31bccb43920406e))

## [0.3.1](https://github.com/SoferAi/torah-dl/compare/v0.3.0...v0.3.1) (2024-12-31)


### Bug Fixes

* tests ([#15](https://github.com/SoferAi/torah-dl/issues/15)) ([e0320be](https://github.com/SoferAi/torah-dl/commit/e0320bea57feeb12db1463056e019464340b6385))

## [0.3.0](https://github.com/SoferAi/torah-dl/compare/v0.2.0...v0.3.0) (2024-12-24)


### Features

* add TorahApp to torah-dl ([#12](https://github.com/SoferAi/torah-dl/issues/12)) ([770173b](https://github.com/SoferAi/torah-dl/commit/770173b31602ae0e755556ccaac6b9a3a94ba720))
* automatic testing ([#10](https://github.com/SoferAi/torah-dl/issues/10)) ([7880a40](https://github.com/SoferAi/torah-dl/commit/7880a4067ace6b6548683c2e7bc96e7e08ea8cae))
* single file extractor config ([#11](https://github.com/SoferAi/torah-dl/issues/11)) ([ac253df](https://github.com/SoferAi/torah-dl/commit/ac253dfb08e198ad8c32b67e56beb05857d26cbb))
* support OUtorah.org links ([#13](https://github.com/SoferAi/torah-dl/issues/13)) ([31b11c6](https://github.com/SoferAi/torah-dl/commit/31b11c6548c8d0b866cba4c0f45671e70bc366fb))
* support TorahAnytime links ([#8](https://github.com/SoferAi/torah-dl/issues/8)) ([b388308](https://github.com/SoferAi/torah-dl/commit/b388308ac8a08ef3fb8fa0c961d5c613edfdc64f))


### Bug Fixes

* readme, docs site ([#6](https://github.com/SoferAi/torah-dl/issues/6)) ([5cff7b1](https://github.com/SoferAi/torah-dl/commit/5cff7b14f29f4d2891aa1c94517116e351c19091))

## [0.2.0](https://github.com/SoferAi/torah-dl/compare/v0.1.0...v0.2.0) (2024-12-04)


### Features

* add yutorah and cli functionality ([#2](https://github.com/SoferAi/torah-dl/issues/2)) ([09320c0](https://github.com/SoferAi/torah-dl/commit/09320c0af7e358f14e3ee9e086efa93a885d6632))
* **docs:** mike and mkdocs ([#4](https://github.com/SoferAi/torah-dl/issues/4)) ([a4b13ef](https://github.com/SoferAi/torah-dl/commit/a4b13efffe124507df10d22f72d5174590827ca9))

## 0.1.0 (2024-11-29)


### Features

* **docs:** update docs ([c0ebdf9](https://github.com/SoferAi/torah-dl/commit/c0ebdf9ad6528b2437f4b38ea24dfbf4fc49c684))
